@@ -37,6 +37,15 @@ novelPointPositionsR <- function(x) {
 #' @export
 #'
 graphROC <- function(modelPredictions, yValues) {
+  if(!is.numeric(modelPredictions)) {
+    stop("WVPlots::graphROC modelPredictions must be numeric")
+  }
+  if(!is.logical(yValues)) {
+    stop("WVPlots::graphROC yValues must be logical")
+  }
+  if(length(modelPredictions)!=length(yValues)) {
+    stop("WVPlots::graphROC must have length(modelPredictions)==length(yValues)")
+  }
   ord <- order(modelPredictions, decreasing=TRUE)
   yValues <- yValues[ord]
   modelPredictions <- modelPredictions[ord]
@@ -351,3 +360,69 @@ ROCPlotPair2 <- function(nm1, frame1, xvar1, truthVar1, truthTarget1,
   plot
 }
 
+
+
+#' Use \code{plotly} to produce a ROC plot.
+#'
+#'
+#' @param d dataframe
+#' @param predCol name of column with numeric predictions
+#' @param outcomeCol name of column with truth
+#' @param outcomeTarget value considred true
+#' @param title character title for plot
+#' @param ...  no unnamed argument, added to force named binding of later arguments.
+#' @return plotly plot
+#'
+#' @examples
+#'
+#'
+#' d <- data.frame(x= 1:5, y= c(TRUE, FALSE , TRUE, TRUE, TRUE))
+#' plotlyROC(d, 'x', 'y', TRUE, 'example plot')
+#'
+#' @export
+#'
+plotlyROC <- function(d, predCol, outcomeCol, outcomeTarget, title,
+                      ...) {
+  checkArgs(frame=d,xvar=predCol,yvar=outcomeCol,title=title,...)
+  prediction <- d[[predCol]]
+  if(!is.numeric(prediction)) {
+    stop("WVPlots:plotlyROC prediction must be numeric")
+  }
+  outcome <- d[[outcomeCol]]==outcomeTarget
+  rocFrame <- WVPlots::graphROC(prediction,
+                                outcome)
+
+  auc <- rocFrame$area
+  returnScores=FALSE
+  nrep=100
+  parallelCluster=NULL
+  aucsig <- sigr::permutationScoreModel(modelValues=prediction,
+                                        yValues=outcome,
+                                        scoreFn=sigr::calcAUC,
+                                        returnScores=returnScores,
+                                        nRep=nrep,
+                                        parallelCluster=parallelCluster)
+  palletName = "Dark2"
+  pString <- sigr::render(sigr::wrapSignificance(aucsig$pValue),format='ascii')
+  aucString <- sprintf('%.2g',auc)
+  subtitle = paste0(
+    'AUC=',aucString,
+    '\n</br>alt. hyp.: AUC(',predCol,')>permuted AUC, ',
+    pString)
+
+  # see https://plot.ly/r/text-and-annotations/
+  plotly::plot_ly(rocFrame$pointGraph,
+                  x = ~FalsePositiveRate,
+                  y = ~TruePositiveRate,
+                  type='scatter',
+                  mode='lines+markers',
+                  hoverinfo= 'text',
+                  text= ~ paste('threshold:', model,
+                                '</br>False Positive Rate:', FalsePositiveRate,
+                                '</br>True Positive Rate:', TruePositiveRate)) ->.;
+    plotly::layout(., title = paste(title,
+                                    '\n</br>',
+                                    outcomeCol, '==', outcomeTarget, ' ~ ', predCol, ', ',
+                                    '\n</br>', subtitle))
+}
+
